
package com.tmerclub.cloud.group.task;

import cn.hutool.core.collection.CollUtil;
import com.tmerclub.cloud.group.model.GroupActivity;
import com.tmerclub.cloud.group.service.GroupActivityService;
import com.tmerclub.cloud.group.service.GroupOrderService;
import com.tmerclub.cloud.group.service.GroupTeamService;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 见 <a href="https://github.com/xuxueli/xxl-job">...</a>
 * 开发步骤：
 * 1、任务开发：在Spring Bean实例中，开发Job方法；
 * 2、注解配置：为Job方法添加注解 "@XxlJob(value="自定义jobhandler名称", init = "JobHandler初始化方法", destroy = "JobHandler销毁方法")"，注解value值对应的是调度中心新建任务的JobHandler属性的值。
 * 3、执行日志：需要通过 "XxlJobHelper.log" 打印执行日志；
 * 4、任务结果：默认任务结果为 "成功" 状态，不需要主动设置；如有诉求，比如设置任务结果为失败，可以通过 "XxlJobHelper.handleFail/handleSuccess" 自主设置任务结果；
 *
 * @author tmerclub
 * @date 2021/04/23
 */
@Component
public class GroupTask {

    @Autowired
    private GroupActivityService groupActivityService;
    @Autowired
    private GroupTeamService groupTeamService;
    @Autowired
    private GroupOrderService groupOrderService;

    /**
     * 结束活动，改变商品类型
     */
    @XxlJob("activityFinishAndProdChange")
    public void activityFinishAndProdChange() {
        XxlJobHelper.log("拼团活动结束，团购商品恢复为普通商品。。。");
        // 0:未启用、1:启用、2:违规下架、3:等待审核
        // 获取活动结束或团单结束未成团的拼团团队
        List<GroupActivity> groupActivityList = groupActivityService.listUnEndButNeedEndActivity();

        if (CollUtil.isEmpty(groupActivityList)) {
            return;
        }
        groupActivityService.changeProdTypeByGroupActivityIdList(groupActivityList);
    }

    /**
     * 初始化原有数据库记录至mongodb
     * 该定时任务成功执行一次即可!!!!!，成功执行完后将任务置为STOP状态或删除
     */
    @XxlJob("initGroupToMongo")
    public void initGroupToMongo() {
        XxlJobHelper.log("初始化拼团团队原有数据库记录至mongodb");
        groupTeamService.initGroupTeamToMongo();

        XxlJobHelper.log("初始化拼团订单原有数据库记录至mongodb");
        groupOrderService.initGroupOrderToMongo();
    }
}
